@@ -39,7 +39,7 @@ class DefaultPrivateViewSetMixin(DefaultPrivateApiViewMixin):
     def perform_create(self, serializer):
         serializer.save(**self.get_defaults())
 
-class OptionalPageViewSetMixin(ModelViewSet):
+class OptionalPageViewSetMixin(generics.GenericAPIView):
     def paginate_queryset(self, queryset, view=None):
         if 'page' in self.request.query_params:
             return super().paginate_queryset(queryset)
@@ -122,7 +122,7 @@ class NonUpdateModelViewset(
     pass
 
 
-class SimpleListViewModelViewSetMixin(ModelViewSet):
+class SimpleListViewModelViewSetMixin(generics.GenericAPIView):
     def get_serializer_class(self):
         if self.action == 'list' and hasattr(self, 'simple_serializer_class'):
             return self.simple_serializer_class
@@ -131,7 +131,7 @@ class SimpleListViewModelViewSetMixin(ModelViewSet):
 
 
 
-class UpdateOrCreateViewSetMixin(ModelViewSet):
+class UpdateOrCreateViewSetMixin(generics.GenericAPIView):
 
     def get_object(self):
         if hasattr(self, "_cached_object"):
